<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <title>disptrace</title>
    <style>
        body {
            margin: 0 0 0 0;
        }
        
        /* http://nicolasgallagher.com/micro-clearfix-hack */
        .cf:before,
        .cf:after {
            content: " "; /* 1 */
            display: table; /* 2 */
        }

        .cf:after {
            clear: both;
        }

        .cf {
            *zoom: 1;
        }

        #header {
            color: white;
            background-color: black;
            margin: 0px 0px 0px 0px;
            width: 100%;
        }
        
        #main {
            margin:5px 10px 5px 10px;
        }
        
        #container {
            float:left;
            width:100%;
            margin-right:-250px;
        }

        #leftbox {
            float:right;
            width:100%;
        }

        #calltrace {
            margin: 0 250px 0 0;
        }

        #modulemenu {
            float:right;
            width: 240px;
        }


        .callstack {
        }

        .callindent {
            margin-left:1em;
        }

        .funcheader {
            background-color: #ECBCBC;
            border: solid 1px;
            padding: 3px;
        }

        .clickable {
            cursor: pointer;
        }
        .clickable:hover {
            text-decoration:underline;
        }
        .funcmenu {
            float:right;
            display: block;
        }

        .modulename {
            font-family: monospace;
        }

        table {
            border-collapse:collapse;
            margin-top: 3px;
            margin-bottom: 5px;
        }

        .funcname{
            font-family: monospace;
        }

        .linenocell {
            width:1px;
            font-family: monospace;
            padding-left: 5px;
            padding-right: 5px;
            text-align: right;
            background-color: #E7ECEE;
            border: solid 1px;
        }

        .codecell {
            font-family: monospace;
            padding-left: 5px;
            white-space: pre;
        }
        
        .funcbutton {
            margin-left:1em;
        }
    </style>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js" type="text/javascript"></script>
    <script language="javascript">
    function hideLines(elemid) {
        var elem = document.getElementById("seq"+elemid);
        if (elem.style.display == "none") {
            elem.style.display = "block";
            document.getElementById("menu"+elemid).innerHTML = "collapse";
        }
        else {
            elem.style.display = "none";
            document.getElementById("menu"+elemid).innerHTML = "expand";
        }
    }
    function hideTrace(src, modulename) {
        if (src.elemhidden != 'hidden') {
            $("."+modulename).css('display', 'none');
            $(".btn-"+modulename).css('color', '#c0c0c0').each(function() {this.elemhidden = 'hidden';});
        }
        else {
            $("."+modulename).css('display', 'block');
            $(".btn-"+modulename).css('color', 'black').each(function() {this.elemhidden = '';});
        }
    }

    </script>
</head>
<body>


<div id="header">
    Disptrace {{created}}
</div>

<div id="main">

<div id="container">
    <div id="leftbox">
        <div id="calltrace">
            {% autoescape false %}
            {{contents}}
            {% endautoescape %}

        </div> <!-- end of calltrace -->
    </div> <!-- end of leftbox -->
</div> <!-- end of container -->


<div id="modulemenu">
{% for module, funcs in modules %}
<div class="modulemenu">
    <div id="abcde" class="modulebutton clickable btn-module-{{module.replace(".", "-")}}"
          onclick="javascript:hideTrace(this, 'module-{{module.replace(".", "-")}}')">{{module}}</div>
    {% for func in funcs %}
        <div class="funcbutton clickable btn-func-{{module.replace(".", "-")}}-{{func.replace(".", "-")}} btn-module-{{module.replace(".", "-")}}"
          onclick="javascript:hideTrace(this, 'func-{{module.replace(".", "-")}}-{{func.replace(".", "-")}}')">{{func}}</div>
    {% endfor %}
</div>
{% endfor %}

</div>

</div> <!-- end of main -->
</body>
</html>

